@@ -13,20 +13,19 @@
 #' the search by setting the parameter value to \code{TRUE}
 #' @param per_page (integer) Number of records to return. Max: 1000. Default: 25
 #' @param page Page (integer) Page numbers start at 1. Default: 1
-#' @param ... Further args passed on to \code{\link[httr]{GET}}
-#' @param id A single Europe PMC article identifier, begins with "PMC", followed by numbers, e.g., 
-#' "PMC3257301"
+#' @param ... curl options passed on to [crul::HttpClient]
+#' @param id A single Europe PMC article identifier, begins with "PMC", followed by 
+#' numbers, e.g.,  "PMC3257301"
 #' 
-#' @return \code{eupmc_search} returns a list with results. \code{eupmc_fields} returns 
-#' a data.frame. \code{eupmc_xml} returns an object of class \code{xml_document}
+#' @return `eupmc_search` returns a list with results. `eupmc_fields` returns 
+#' a data.frame. `eupmc_xml` returns an object of class `xml_document`
 #' @details resulttype parameter options:
-#' \itemize{
-#'  \item idlist - returns a list of IDs and sources for the given search terms
-#'  \item lite - returns key metadata for the given search terms; this is the default 
+#' 
+#' - idlist - returns a list of IDs and sources for the given search terms
+#' - lite - returns key metadata for the given search terms; this is the default 
 #'  value if the parameter is unspecified.
-#'  \item core - returns full metadata for a given publication ID; including abstract, 
+#' - core - returns full metadata for a given publication ID; including abstract, 
 #'  full text links, and MeSH terms.
-#' }
 #' 
 #' @examples \dontrun{
 #' # search
@@ -45,16 +44,23 @@
 #' # get full text XML
 #' eupmc_xml('PMC3257301')
 #' }
-eupmc_search <- function(query, resulttype = NULL, synonym = FALSE, per_page = 25, page = 1, ...) {
+eupmc_search <- function(query, resulttype = NULL, synonym = FALSE, per_page = 25, 
+  page = 1, ...) {
+
   is_it(per_page, "numeric")
   is_it(page, "numeric")
   is_it(synonym, "logical")
-  args <- ft_compact(list(query = query, resulttype = resulttype, synonym = ft_as_log(synonym), 
-                          pageSize = per_page, page = page, format = "json"))
+  args <- ft_compact(list(query = query, resulttype = resulttype, 
+    synonym = ft_as_log(synonym), pageSize = per_page, page = page, 
+    format = "json"))
   newargs <- paste(names(args), args, sep = "=", collapse = "&")
-  out <- GET(URLencode(paste0(eupmc_base(), "search/", newargs)), ...)
+  cli <- crul::HttpClient$new(
+    url = utils::URLencode(paste0(eupmc_base(), "search/", newargs)),
+    opts = list(...)
+  )
+  out <- cli$get()
   eupmc_errors(out)
-  tt <- content(out, "text", encoding = "UTF-8")
+  tt <- out$parse("UTF-8")
   jsonlite::fromJSON(tt)
 }
 
@@ -62,23 +68,27 @@ eupmc_search <- function(query, resulttype = NULL, synonym = FALSE, per_page = 2
 #' @keywords internal
 #' @rdname eupmc
 eupmc_fields <- function(...) {
-  out <- GET(URLencode(paste0(eupmc_base(), "fields")), ...)
+  cli <- crul::HttpClient$new(
+    url = utils::URLencode(paste0(eupmc_base(), "fields")),
+    opts = list(...))
+  out <- cli$get()
   eupmc_errors(out)
-  tt <- content(out, "text", encoding = "UTF-8")
+  tt <- out$parse("UTF-8")
   tmp <- xml2::as_list(xml2::read_xml(tt))
-  out <- lapply(tmp$searchTermList, function(z) {
-    setNames(rbind.data.frame(z), c('term', 'datasets'))
-  })
-  do.call("rbind.data.frame", unname(out))
+  data.frame(terms = unname(unlist(lapply(tmp$searchTermList, "[[", "term"))), 
+    stringsAsFactors=FALSE)
 }
 
 #' @export
 #' @keywords internal
 #' @rdname eupmc
 eupmc_xml <- function(id, ...) {
-  out <- GET(URLencode(paste0(eupmc_base(), id, "/fullTextXML")), ...)
+  cli <- crul::HttpClient$new(
+    url = utils::URLencode(paste0(eupmc_base(), id, "/fullTextXML")), 
+    opts = list(...))
+  out <- cli$get()
   eupmc_errors(out)
-  tt <- content(out, "text", encoding = "UTF-8")
+  tt <- out$parse("UTF-8")
   xml2::read_xml(tt)
 }
 
@@ -97,5 +107,5 @@ eupmc_errors <- function(x) {
 }
 
 is_it <- function(x, y) {
-  if (!is(x, y)) stop(sprintf("%s must be %s", deparse(substitute(x)), y), call. = FALSE)  
+  if (!inherits(x, y)) stop(sprintf("%s must be %s", deparse(substitute(x)), y), call. = FALSE)  
 }
