@@ -11,7 +11,7 @@ plugin_links_entrez <- function(sources, ids, opts, ...){
       rbind_fill(lapply(z, function(w) {
         w <- unclass(w)
         df <- data.frame(w, stringsAsFactors = FALSE)
-        setNames(df, tolower(names(df)))
+        stats::setNames(df, tolower(names(df)))
       }))
     })
     list(found = length(ft_compact(out)), ids = names(out), data = out, opts = opts)
@@ -23,8 +23,8 @@ plugin_links_entrez <- function(sources, ids, opts, ...){
 plugin_links_plos <- function(sources, ids, opts, ...){
   if (any(grepl("plos", sources))) {
     ids <- grep("annotation", ids, value = TRUE, invert = TRUE)
-    tmp <- as.list(setNames(rplos::full_text_urls(ids), ids))
-    tmp <- lapply(tmp, function(z) list(xml = z, pdf = sub("XML", "PDF", z)))
+    tmp <- as.list(stats::setNames(rplos::full_text_urls(ids), ids))
+    tmp <- lapply(tmp, function(z) list(xml = z, pdf = sub("manuscript", "printable", z)))
     list(found = length(tmp), ids = names(tmp), data = tmp, opts = opts)
   } else {
     emptylist(opts)
@@ -33,15 +33,21 @@ plugin_links_plos <- function(sources, ids, opts, ...){
 
 plugin_links_crossref <- function(sources, ids, opts, ...){
   if (any(grepl("crossref", sources))) {
-    tmp <- lapply(ids, cr_ft_links, type = "all")
+    safe_crm_links <- function(x, type = "xml", ...) {
+      tryCatch(crminer::crm_links(x, type, ...), error = function(e) NULL)
+    }
+    tmp <- ft_compact(lapply(ids, safe_crm_links, type = "all"))
     out <- lapply(tmp, function(z) {
       rbind_fill(lapply(z, function(w) {
-        data.frame(list(url = w[1], doi = attr(w, "doi"), type = attr(w, "type")), stringsAsFactors = FALSE)
+        data.frame(url = w[[1]], doi = attr(w, "doi"), type = attr(w, "type"),
+                   member = attr(w, "member") %||% "", 
+                   stringsAsFactors = FALSE)
       }))
     })
     out <- ft_compact(out)
-    out <- setNames(out, sapply(out, function(x) x$doi[1]))
-    list(found = length(ft_compact(out)), ids = names(out), data = out, opts = opts)
+    out <- stats::setNames(out, sapply(out, function(x) x$doi[1]))
+    list(found = length(ft_compact(out)), ids = names(out), 
+         data = out, opts = opts)
   } else {
     emptylist(opts)
   }
@@ -49,7 +55,7 @@ plugin_links_crossref <- function(sources, ids, opts, ...){
 
 plugin_links_bmc <- function(sources, ids, opts, ...){
   if (any(grepl("bmc", sources))) {
-    tmp <- setNames(bmc_link(ids), ids)
+    tmp <- stats::setNames(bmc_link(ids), ids)
     list(found = length(tmp), ids = names(tmp), data = tmp, opts = opts)
   } else {
     emptylist(opts)
@@ -77,7 +83,7 @@ bmc_link <- function(dois) {
 
 plugin_links_elife <- function(sources, ids, opts, ...){
   if (any(grepl("elife", sources))) {
-    tmp <- setNames(elife_link(ids), ids)
+    tmp <- stats::setNames(elife_link(ids), ids)
     list(found = length(tmp), ids = names(tmp), data = tmp, opts = opts)
   } else {
     emptylist(opts)
@@ -105,7 +111,7 @@ plugin_links_peerj <- function(sources, ids, opts, ...){
 peerj_link <- function(dois) {
   xmlbase <- "https://peerj.com/articles/%s.xml"
   pdfbase <- "https://peerj.com/articles/%s.pdf"
-  setNames(lapply(dois, function(x) {
+  stats::setNames(lapply(dois, function(x) {
     x <- strsplit(x, "peerj\\.")[[1]][2]
     list(xml = sprintf(xmlbase, x), pdf = sprintf(pdfbase, x))
   }), dois)
@@ -123,7 +129,7 @@ plugin_links_frontiersin <- function(sources, ids, opts, ...){
 frontiersin_link <- function(dois) {
   xmlbase <- "http://journal.frontiersin.org/article/%s/xml/nlm"
   pdfbase <- "http://journal.frontiersin.org/article/%s/pdf"
-  setNames(lapply(dois, function(x) {
+  stats::setNames(lapply(dois, function(x) {
     list(xml = sprintf(xmlbase, x), pdf = sprintf(pdfbase, x))
   }), dois)
 }
@@ -140,7 +146,7 @@ plugin_links_copernicus <- function(sources, ids, opts, ...){
 copernicus_link <- function(dois) {
   xmlbase <- "http://www.ann-geophys.net/%s/%s/%s/%s.xml"
   pdfbase <- "http://www.ann-geophys.net/%s/%s/%s/%s.pdf"
-  setNames(lapply(dois, function(x) {
+  stats::setNames(lapply(dois, function(x) {
     x <- strsplit(x, "/")[[1]][2]
     pcs <- strsplit(x, "-")[[1]]
     list(xml = sprintf(xmlbase, pcs[2], pcs[3], pcs[4], x), 
@@ -160,7 +166,7 @@ plugin_links_cogent <- function(sources, ids, opts, ...){
 cogent_link <- function(dois) {
   xmlbase <- "http://cogentoa.tandfonline.com/doi/xml/"
   pdfbase <- "http://cogentoa.tandfonline.com/doi/pdf/"
-  setNames(lapply(dois, function(x) {
+  stats::setNames(lapply(dois, function(x) {
     list(xml = paste0(xmlbase, x), pdf = paste0(pdfbase, x))
   }), dois)
 }
